==> deepin-calculator_6.0.0.tar.xz: BUILD/translations/deepin-calculator_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Chyba ve výrazu</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Vymazat celou paměť kalkulačky</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Vymazat historii</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Kalkulačka</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Standardní</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Vědecký</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>Kalkulačka je jednoduchá a snadno použitelná. Podporuje standardní a vědecký a programátorský režim.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programátorské</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Vymazat položku v paměti kalkulačky</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Vymazat paměť kalkulačky</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Vyvolání obsahu paměti kalkulačky</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Přidat položku do paměti kalkulačky</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Přidat do paměti kalkulačky</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Odečíst od položky v paměti kalkulačky</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Odečíst obsah paměti kalkulačky</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Uložení paměti kalkulačky</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Paměť kalkulačky</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Vymazat položku v paměti kalkulačky</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Přidat položku do paměti</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Odečíst od položky v paměti kalkulačky</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>V paměti kalkulačky není nic uloženo</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Chyba ve výrazu</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Aritmetický posuv</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Logický posuv</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Kruhový posuv</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Otočit bitovou rotací</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Aritmetický posuv</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Logický posuv</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Kruhový posuv</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Otočit bitovou rotací</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Kalkulačka</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Chyba ve výrazu</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Paměť kalkulačky</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Chyba ve výrazu</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Žádná historie</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.9.tar.xz: BUILD/translations/deepin-calculator_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Chyba ve výrazu</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Vymazat celou paměť kalkulačky</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Vymazat historii</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>Použít oddělovač tisíců</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>Použít oddělovač desetitisíců</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Kalkulačka</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Standardní</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Vědecký</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>Kalkulačka je jednoduchá a snadno použitelná. Podporuje standardní a vědecký a programátorský režim.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programátorský</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Vymazat položku v paměti kalkulačky</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Vymazat celou paměť kalkulačky</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Vyvolání obsahu paměti kalkulačky</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Přidat položku do paměti kalkulačky</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Přidat do paměti kalkulačky</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Odečíst od položky v paměti kalkulačky</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Odečíst obsah paměti kalkulačky</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Uložení paměti kalkulačky</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Paměť kalkulačky</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Vymazat položku v paměti kalkulačky</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Přidat položku do paměti kalkulačky</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Odečíst od položky v paměti kalkulačky</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>V paměti kalkulačky není nic uloženo</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Chyba ve výrazu</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Aritmetický posuv</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Logický posuv</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Kruhový posuv</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Otočit bitovou rotací</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Aritmetický posuv</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Logický posuv</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Kruhový posuv</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Otočit bitovou rotací</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Kalkulačka</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Chyba ve výrazu</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Paměť kalkulačky</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Chyba ve výrazu</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Žádná historie</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
</TS>
